@@ -50,9 +50,9 @@ class Encoding():
             else:
                 print(decode,end="")
     def findrate(self):
-        print(self.rate)
-        for k,v,i in self.encoding.reverse:
-            print(f'{i}:  {k}:{v},')
+        print(f'Rate of {self} is {self.rate}')
+        for k,v in self.encoding.reverse.items():
+            print(f'{k}:{v}',end='  ')
 class ListEncoding():
     def __init__(self,mix):
         self.encoding = []
